Split

Struct Split 

pub struct Split<'r, R: AsyncBufRead> { /* private fields */ }
Available on crate feature std only.
Stream for AsyncBufReadExt::split.

The lifetime parameter of this type is an implementation detail, and it should be set to the lifetime of R. For example, if R is Empty is should be 'static and if R is Cursor<&'a [u8]> it should be 'a.